import requests
import pandas as pd
import sys


def api_call(series: str) -> pd.DataFrame:
    """
    A function that return historical values for Brazil's IPCA (Broad Consumers Price Index) in a Pandas.DataFrame format.

    Params:
        series -> specifies the type of values wanted.
            if monthly values are desided, then series='monthly'
            otherwise series='yearly'
    """
    base_url = "http://www.ipeadata.gov.br/api/odata4/Metadados"
    series_dict = {"yearly": "('PRECOS_IPCAG')", "monthly": "('PRECOS12_IPCA15G12')"}
    series_type = ""
    if series == "yearly":
        series_type = series_dict["yearly"]
    elif series == "monthly":
        series_type = series_dict["monthly"]
    else:
        print("Incorrect value. Series arguments must be either 'yearly' or 'monthly'.")
        sys.exit(1)
    complete_url = f"{base_url}{series_type}" + "/Valores"
    data = requests.get(complete_url)
    if data.status_code == requests.codes.ok:
        data = data.json()
        if "value" in data:
            try:
                data = pd.DataFrame(data["value"])
                data = data[["SERCODIGO", "VALDATA", "VALVALOR"]]
                data = data.rename(
                    {"SERCODIGO": "series", "VALDATA": "date", "VALVALOR": "ipca"},
                    axis=1,
                )
                data["date"] = pd.to_datetime(
                    data["date"].apply(pd.to_datetime), utc=True, format="%Y-%m-%d"
                )
                return data
            except Exception:
                return None


if __name__ == "__main__":
    api_call()



import pandas as pd
import sys
from datetime import datetime
from deflator.api_call import api_call


def deflate(
    data_frame: pd.DataFrame,
    value_column: str,
    date_column,
    deflate_year=None,
    deflate_month=None,
):
    series = ""
    target_date = None
    if not value_column:
        print("You must especify the column to be deflated.")
        sys.exit(1)
    if not deflate_year:
        print("At least the deflate_year argument must be specified")
        sys.exit(1)
    if not deflate_month:
        series = "yearly"
        date_format = "%Y"
        target_date = int(
            pd.to_datetime(datetime(deflate_year, 1, 1)).strftime(date_format)
        )
        conversion_type = "int"
    else:
        series = "monthly"
        date_format = "%Y-%m"
        target_date = pd.to_datetime(datetime(deflate_year, deflate_month, 1)).strftime(
            date_format
        )
        conversion_type = "object"

    ipca_values = api_call(series=series)

    ipca_values = ipca_values[["date", "ipca"]]

    ipca_values["date"] = (
        ipca_values["date"].dt.strftime(date_format).astype(conversion_type)
    )
    data_frame[date_column] = data_frame[date_column].astype(conversion_type)
    temp_df = pd.merge(
        left=data_frame,
        right=ipca_values,
        left_on=date_column,
        right_on="date",
        how="left",
    )

    deflator = temp_df.loc[temp_df["date"] == target_date]["ipca"].squeeze()

    temp_df["deflated_value"] = temp_df[value_column] * (
        deflator / temp_df["ipca"].squeeze()
    )

    data_frame["deflated_value"] = temp_df["deflated_value"]
    return data_frame
    """return {'data_frame':data_frame,'deflator':deflator,'temp_df':temp_df,'ipca_values':ipca_values,
            'target_date':target_date,'target_date':target_date,'conversion_type':conversion_type}"""

if __name__ =='__main__':
    deflate()


import setuptools

setuptools.setup(
    name="deflatepybr",
    version="0.0.1",
    author="Thiago Eugênio",
    description="A simple package to deflate BR currency values using IPCA's historical yearly and monthly indexes",
    packages=["deflator"]
)